@@ -1,4 +1,4 @@
-import settings
+from django.conf import settings
 from django.contrib.gis.utils.geoip import GeoIP
 
 def addgeoip(request):
@@ -28,4 +28,4 @@ def addgeoip(request):
         return {'country': user_country,
                 'in_country' : bool(user_country in allowed_countries)}
     else:
-        return {}
\ No newline at end of file
+        return {}
